Learn R Programming

JoSAE (version 0.1)

JoSAE.domain.data: Dataframe containing the domains population and number of elements and mean of the auxiliary variable

Description

Auxiliary variable: Mean canopy height derived from a photogrammetric canopy height model

Usage

data(JoSAE.domain.data)

Arguments

source

Breidenbach and Astrup (2011)

References

Breidenbach and Astrup (2011)

See Also

JoSAE-package for more examples

Examples

Run this code
data(JoSAE.domain.data)

str(JoSAE.domain.data)

Run the code above in your browser using DataLab