JoSAE.sample.data: Sample plots of the Norwegian National Forest Inventory (NNFI) with
a variable of interest and an auxiliary variable
Description
Above ground forest biomass over all tree species is the variable of
interest. Mean canopy height derived from a photogrammetric canopy
height model of 20~cm geometric and 10~cm radiometric
resolution is the auxiliary variable.
Usage
data(JoSAE.sample.data)
Arguments
source
Breidenbach, J. and Astrup, R. (2012), Small area estimation of
forest attributes in the Norwegian National Forest Inventory. European
Journal of Forest Research, 131:1255-1267.