Learn R Programming

JoSAE (version 0.2.2)

nfi: Sample plots of the Norwegian National Forest Inventory (NFI) with a variable of interest and an auxiliary variable

Description

A total of 131 sample plots of the Norwegian National Forest Inventory (NFI) with timber volume interpolated and extrapolated to the year 2011 as the variable of interest and mean vegetation height derived from image matching as the auxiliary variable.

Usage

data(nfi)

Arguments

source

Breidenbach, J., Ronald E. McRoberts, Astrup, R. (2015), Empirical coverage of model-based variance estimators for remote sensing assisted estimation of stand-level timber volume. Remote Sensing of Environment. In press.

See Also

JoSAE-package and Vignette for more examples

Examples

Run this code
data(nfi)
plot(vol.2011~Elev.Mean, nfi)

Run the code above in your browser using DataLab