landsat data.frame is a compilation (by Battese et al., 1988)
of survey and satellite data. It consists of data on segments (primary
sampling unit; 1 segement =approx= 250 hectares) under corn and soybeans
for 12 counties in north-central Iowa; see Details, below.The landsat data.frame was made available by Tobias Schoch with the R package rsae. Since rsae was archived as of R 3.0.2, the data and this description was copied from rsae 0.1-4 in the archives.
data(landsat)landsat is from Table 1 of Battese et al. (1988,
p. 29).
Schoch (2011) rsae: Robust Small Area Estimation, R package version 0.1-4: http://cran.r-project.org/src/contrib/Archive/rsae/rsae_0.1-4.tar.gzlandsat data is a compilation (by Battese et al., 1988) of the LANDSAT satellite data from the U.S. Department of Agriculture (USDA) and the 1978 June Enumerative Survey. Data for more than one sample segment are available for several counties (i.e, unbalanced data).
Observations No. 33 has been flaged as outlier (cf., Battese et al. (1988, p. 28).